# Step 5: Create AI-Related Transformations
Create a strategic plan for transformations involving AI, focusing on areas with high AI potential and aligning AI initiatives with your business objectives.
After gaining a comprehensive overview of AI technologies within your IT landscape, the next step is planning AI-related transformations. This involves developing a strategy on how to best integrate and optimize AI technologies within your organization. You can identify areas where AI can be leveraged to transform business capabilities and applications and then create a detailed roadmap for these transformations.
Track and manage your transformation projects using initiative fact sheets. You can create an initiative fact sheet for each transformation initiative, documenting key information such as the project's objectives, timeline, resources, and associated applications or IT components. To ensure alignment with your organization's strategic goals, you can create objective fact sheets for AI-related objectives. For more information about these fact sheet types, see:
  * [Initiative Modeling Guidelines](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model initiatives. This includes best practices and applicable use cases, and common antipatterns.")
  * [Objective Modeling Guidelines](https://help.sap.com/docs/leanix/ea/objective-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model objectives. This includes best practices and applicable use cases, and common antipatterns.")


Within each initiative fact sheet, link the project to the relevant applications or IT components. This provides a clear view of which parts of your IT landscape are affected by the transformation and helps coordinate efforts across different parts of your organization.
To visualize your AI-related projects, use the roadmap report. Apply filters for specific AI-related objectives to the report. To learn more about this report type, see [Roadmap Report](https://help.sap.com/docs/leanix/ea/roadmap-report?locale=en-US&state=PRODUCTION&version=CLOUD).
![Planning AI-Related Transformations Using the Roadmap Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757f1437a441014a9a7e16172e979e4_LowRes.png)
Planning AI-Related Transformations Using the Roadmap Report
If your organization uses SAP LeanIX Architecture and Road Map Planning, which is an additional product, you can visualize your transformation projects over time. You can create a roadmap for each transformation initiative, showing when different applications or IT components will be affected. This helps ensure that your transformations are well-planned and coordinated, and that they align with your overall enterprise architecture strategy. To learn more, see [SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD "The SAP LeanIX Architecture and Road Map Planning enhances SAP LeanIX Application Portfolio Management by offering advanced features for seamless planning and execution of transformation initiatives in enterprise architecture management.").
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
